Synchronous acquisition functions
=================================

This section describes the synchronous functions implemented in :mod:`pymanip` for
signal acquisition on DAQmx and Scope boards.
New scripts should preferably use the newer :mod:`pymanip.aiodaq` instead.

.. automodule:: pymanip.daq.DAQmx

.. automodule:: pymanip.daq.Scope
